Learn R Programming

realTimeloads (version 1.0.0)

attenuation_of_sound_by_water: Compute attenuation of sound in water given frequency, temperature, and salinity

Description

Computes attenuation of sound in water per Ainslie and McColm (1998)

Usage

attenuation_of_sound_by_water(freq, temp, sal)

Value

attenuation of sound in water (dB/m), divide by 20*log10(exp(1)) to convert to Nepers/m

Arguments

freq

frequency of sound (Hz)

temp

Water temperature (degrees C)

sal

Salinity (PSU)

Author

Daniel Livsey (2023) ORCID: 0000-0002-2028-6128

References

Ainslie, M. A., & McColm, J. G. (1998). A simplified formula for viscous and chemical absorption in sea water. The Journal of the Acoustical Society of America, 103(3), 1671-1672.

Author modified Matlab code from David Schoellhamer

Examples

Run this code
InputData <- realTimeloads::ExampleData
freq <- InputData$ADCP$Accoustic_Frequency_kHz*1000
cond <-InputData$Sonde$Conductivity_uS_per_cm
temp <- InputData$Sonde$Water_Temperature_degC
dbar <- InputData$Sonde$Pressure_dbar
sal <- ctd2sal(cond,temp,dbar)
aw <- attenuation_of_sound_by_water(freq,temp,sal) # dB/m
awNp <- attenuation_of_sound_by_water(freq,temp,sal)/(20*log10(exp(1))) # Np/m

Run the code above in your browser using DataLab